CachedS5Manager class

Constructors

CachedS5Manager({required S5 s5})

Properties

cacheDir Directory?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
s5 → S5
final

Methods

clear() Future<void>
This deletes the entire local cache.
getBytesFromCID(String cid) Future<Uint8List>
Given a compliant CID string, it fetches and caches that assets. NOTE: Because of limitations, this will skip the caching section if it is running from the web
getCacheFile(String cid) Future<File>
Grabs the local cache file. This should NOT get called on web or things will break.
getFileFromCID(String cid) Future<File?>
Given a compliant CID string, it fetches and caches that assets. NOTE: Because of limitations, this will NOT WORK on web
init() Future<void>
Initializes the cache dir, nothing else will work unless you do this first.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited