getCacheFile method

Future<File> getCacheFile(
  1. String cid
)

Grabs the local cache file. This should NOT get called on web or things will break.

Implementation

Future<File> getCacheFile(String cid) async {
  if (cacheDir != null) {
    return File(join(cacheDir!.path, cid));
  } else {
    await init();
    return File(join(cacheDir!.path, cid));
  }
  // TODO: Add automatic cache prune based on max size & oldest files
}