CachedS5Manager class
Methods
clear ()
→ Future <void >
This deletes the entire local cache.
getBytesFromCID (String cid )
→ Future <Uint8List >
Given a compliant CID string, it fetches and
caches that assets.
NOTE: Because of limitations, this will skip the caching section if
it is running from the web
getCacheFile (String cid )
→ Future <File >
Grabs the local cache file.
This should NOT get called on web or things will break.
getFileFromCID (String cid )
→ Future <File ? >
Given a compliant CID string, it fetches and
caches that assets.
NOTE: Because of limitations, this will NOT WORK on web
init ()
→ Future <void >
Initializes the cache dir, nothing else will work unless you do this first.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited